=================================
Nova-dpm specifications for Ocata
=================================

**TODO:** Figure out what to do with this page and its child pages.

Template:

.. toctree::
   :maxdepth: 1

   Specification Template (Ocata release) <template>

Specs implemented in Ocata:

.. toctree::
   :glob:
   :maxdepth: 1

   implemented/*

Specs approved (but not implemented) in Ocata:

.. toctree::
   :glob:
   :maxdepth: 1

   approved/*
